@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical basslines
 
-our $VERSION = '0.0606';
+our $VERSION = '0.0607';
 
 use Moo;
 use strictures 2;
@@ -151,7 +151,7 @@ sub generate {
     if ($self->positions && $scale) {
         my @scale = get_scale_MIDI($chord_note, $self->octave, $scale);
         for my $n (0 .. $#scale) {
-            push @pitches, $scale[$n] if grep { $_ == $n } $self->positions->{$scale}->@*;
+            push @pitches, $scale[$n] if grep { $_ == $n } @{ $self->positions->{$scale} };
         }
     }
     elsif ($scale) {
@@ -318,7 +318,7 @@ Music::Bassline::Generator - Generate musical basslines
 
 =head1 VERSION
 
-version 0.0606
+version 0.0607
 
 =head1 SYNOPSIS
 
